@@ -50,7 +50,7 @@ similar solutions like this...)
 use warnings;
 use strict;
 
-our $VERSION = '0.05_01';
+our $VERSION = '0.05_02';
 
 =head1 METHODS
 
@@ -116,6 +116,12 @@ compare local machine time with a ntp server to make sure both are in the sync.
 
 For the idea thanks to Emmanuel Rodriguez Santiago.
 
+=item 02_messages.t
+
+Checks a file(s) and generates failed tests on every line found there.
+Allows any program in the system to pass messages to the monitoring simply by
+adding line into a file
+
 =item 03_sites-ok.t
 
 check web sites
@@ -142,6 +148,21 @@ File directory permissions and sizes for a directories
 
 For the idea thanks to Peter Hartl.
 
+=item 03_interfaces-ptr.t
+
+check if interfaces has a PTR record which properly resolves back to interface ip
+
+=item 03_wakeup.t
+
+After given number of days a fail test will occure. The purpose is to make sure
+monitoring team is receiving alarms properly. If the admins finds out that this
+test fails for couple of days without anyone notice then there is something
+wrong.
+
+=item 03_net-hops.t
+
+Does traceroute and check first or last N network hops to the host. It's using system
+C<traceroute> program.
 
 =back
 
@@ -159,11 +180,7 @@ Check out the F<Build.PL> for the list of examples that are installed in F</etc/
 Any wishes || good ideas for general server tests should go here.
 Do you have any? Send it! Or even better send the .t file.
 
-	* check if all the interfaces has dns revers rr that properly resolves back
-	* I should write some easy example test for non perl admins
-	* traceroute and check first N (all?) hops to the host (Net::Traceroute::PurePerl ?)
-	
-	* create Test::Server::Smoke to try examples on smoke testing servers
+	* connect to database and check if count of rows in all table doesn't exceed some number
 
 =head1 LINKS
 
